aboutsummaryrefslogtreecommitdiff
path: root/object/tag/serialize.go
diff options
context:
space:
mode:
Diffstat (limited to 'object/tag/serialize.go')
-rw-r--r--object/tag/serialize.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/object/tag/serialize.go b/object/tag/serialize.go
index 4f9d6664..43fad522 100644
--- a/object/tag/serialize.go
+++ b/object/tag/serialize.go
@@ -9,8 +9,8 @@ import (
objecttype "codeberg.org/lindenii/furgit/object/type"
)
-// SerializeWithoutHeader renders the raw tag body bytes.
-func (tag *Tag) SerializeWithoutHeader() ([]byte, error) {
+// BytesWithoutHeader renders the raw tag body bytes.
+func (tag *Tag) BytesWithoutHeader() ([]byte, error) {
if tag.Target.Algorithm().Size() == 0 {
return nil, errors.New("object: tag: missing target id")
}
@@ -48,9 +48,9 @@ func (tag *Tag) SerializeWithoutHeader() ([]byte, error) {
return buf.Bytes(), nil
}
-// SerializeWithHeader renders the raw object (header + body).
-func (tag *Tag) SerializeWithHeader() ([]byte, error) {
- body, err := tag.SerializeWithoutHeader()
+// BytesWithHeader renders the raw object (header + body).
+func (tag *Tag) BytesWithHeader() ([]byte, error) {
+ body, err := tag.BytesWithoutHeader()
if err != nil {
return nil, err
}